"""
Global topics on the message bus.
"""

AUTH = 'EO-AUTH'
CERTS = 'EO-CERTS'
DELEGATES = 'EO-DELEGATES'
KEYS = 'EO-KEYS'
MEASUREMENTS = 'EO-MEASUREMENTS'
MEASUREMENTS_COMMANDS = 'EO-MEASUREMENTS-COMMANDS'
METERINGPOINTS = 'EO-METERINGPOINTS'
METERINGPOINTS_COMMANDS = 'EO-METERINGPOINTS_COMMANDS'
TECHNOLOGIES = 'EO-TECHNOLOGIES'
USERS = 'EO-USERS'



from dataclasses import dataclass

from origin.bus import Message
from origin.models.delegates import MeteringPointDelegate


@dataclass
class MeteringPointDelegateGranted(Message):
    """
    An actor (identified by its subject) has been delegated
    access to a MeteringPoint.
    """
    delegate: MeteringPointDelegate


@dataclass
class MeteringPointDelegateRevoked(Message):
    """
    An actor (identified by its subject) has had its delegated
    access to a MeteringPoint revoked.
    """
    delegate: MeteringPointDelegate



from .app import Application  # noqa: F401
from .cookies import Cookie  # noqa: F401
from .context import Context  # noqa: F401
from .endpoint import Endpoint  # noqa: F401
from .guards import EndpointGuard, ScopedGuard, TokenGuard  # noqa: F401
from .responses import (  # noqa: F401
    HttpResponse,
    HttpError,
    MovedPermanently,
    TemporaryRedirect,
    BadRequest,
    Unauthorized,
    Forbidden,
    InternalServerError,
)
